/******************************************************************************\
*	Maps.js
*	Project : Geoportail-Shortcode
*	Date : 10/05/12
*	Auteur : geoWP
\******************************************************************************/


/*----------------------------------------------------------------------------*\
* function create_map
* params :
*	id,type,lat,lon,z,territory,geolocate
*	layers_array,kml_array,gpx_array,geotag 
* TODO:
*	gpx_graph ?
*	wms ?
\*----------------------------------------------------------------------------*/
function create_map(params) {
	//options for creating viewer:
	var options= OpenLayers.Util.extend(
		{
			territory:params.territory,
			mode:params.type
			//projection:"IGNF:GEOPORTALFXX",
			//displayProjection:"IGNF:RGF93G"
		},
		gGEOPORTALRIGHTSMANAGEMENT
	);
	var viewer= new Geoportal.Viewer.Default("map_"+params.id,options);
	if (!viewer) {
		// problem ...
		OpenLayers.Console.error("Création de la carte échouée");
		return;
	}
	var map = viewer.getMap();
// Avanced Layers
	var layers_array = params.layers_array;
	for(var i=0;i<layers_array.length;i++)
	{
		var layer_options =
			{
				opacity:layers_array[i].opacity,
				visibility:layers_array[i].visibility
			};
		viewer.addGeoportalLayer(layers_array[i].name,layer_options);
	}
//Center Map
	map.setCenterAtLonLat(params.lon,params.lat,params.z);
//kml_array
	var kml_array = params.kml_array;
	for(var i=0;i<kml_array.length;i++)
	{
		map.addLayer(
			"KML",
			kml_array[i].name,
			kml_array[i].url,
			{
				visibility:true,
				minZoomLevel:3,
				maxZoomLevel:16
			}
		);
	}
//gpx_array
	var gpx_array = params.gpx_array;
	for(var i=0;i<gpx_array.length;i++)
	{
		map.addLayer(
			"GPX",
			gpx_array[i].name,
			gpx_array[i].url,
			{
				visibility:true,
				minZoomLevel:1,
				maxZoomLevel:16,
				styleMap: new OpenLayers.StyleMap({
					strokeColor: "blue",
					strokeWidth: 5,
					strokeOpacity: 0.8,
					fillOpacity: 0.2,
					fillColor: "blue"
				})
			}
		);
	}
/******************************************************************************/
//wms
/*
		if($attr['wms'] != '') 
		{
			$returnme .= '
					map.addLayer(
						"WMS",
						"' . $attr['wms_title'] . '",
						"' . $attr['wms'] . '",
	                		   	{layers: "' . $attr['wms_layer'] . '"},
		                   		{transitionEffect: "resize"}	
					);
			';
		}
*/
/******************************************************************************/
//geolocate
	if(params.geolocate != 'false')
	{
		var geolocate = new OpenLayers.Control.Geolocate({
			bind: true,
			geolocationOptions: {
				enableHighAccuracy: false,
				maximumAge: 0,
				timeout: 7000
			}
		});
		map.addControl(geolocate);
		var pulsate = function(feature) {
		var point = feature.geometry.getCentroid(),
		    bounds = feature.geometry.getBounds(),
		    radius = Math.abs((bounds.right - bounds.left)/2),
		    count = 0,
		    grow = "up";
		var resize = function(){
		        if (count>16) {
		            clearInterval(window.resizeInterval);
				}
		        var interval = radius * 0.03;
		        var ratio = interval/radius;
		        switch(count) {
		            case 4:
		            case 12:
	        	        grow = "down"; break;
		            case 8:
		                grow = "up"; break;
		        }
		        if (grow!=="up") {
		            ratio = - Math.abs(ratio);
	        	}
		        feature.geometry.resize(1+ratio, point);
		        vector.drawFeature(feature);
		        count++;
		    };
	    	window.resizeInterval = window.setInterval(resize, 50, point, radius);
		};
		var vector = new OpenLayers.Layer.Vector("myLocation");
		map.addLayers([vector]);
		geolocate.events.register("locationupdated",geolocate,function(e) {
			map.setCenterAtLonLat(
									e.point.x,
									e.point.y,
									params.z
                               	);
			vector.removeAllFeatures();
			var circle = new OpenLayers.Feature.Vector(
			        OpenLayers.Geometry.Polygon.createRegularPolygon(
			            new OpenLayers.Geometry.Point(e.point.x, e.point.y),
			            e.position.coords.accuracy/2,
   							40,
   							0
					),
					{},
					{
				    fillColor: "#000",
				    fillOpacity: 0.1,
				    strokeWidth: 0
				}
			   );
			vector.addFeatures([
			        new OpenLayers.Feature.Vector(
			            e.point,
				    {},
			            {
			                graphicName: "cross",
			                strokeColor: "#f00",
			                strokeWidth: 2,
			                fillOpacity: 0,
			                pointRadius: 10
			            }
			        ),
			        circle
			    ]);
			pulsate(circle);
		});
		geolocate.activate();
	}
//geotags
	if(params.geotag.enabled != 'false')
		map.setCenterAtLonLat(params.geotag.lon,params.geotag.lat,params.z);
};//function;
